-----------------------------------------------------------------------------------------------
-- Client Lua Script for SlimChallenges
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Apollo"
require "GameLib"
require "Window"
require "Unit"

-------------------------------------------------------------------------------------
-- SlimChallenges Module Definition
-----------------------------------------------------------------------------------------------
local SlimChallenges = {}
local ok = 0 
local runOnce = true
local kcrDoubleMarkerOff 		= ApolloColor.new("UI_BtnTextHoloNormal")
local challengesAddon_OnDocumentReady = nil
local challengesAddon = Apollo.GetAddon("Challenges")

-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function SlimChallenges:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    return o
end

function SlimChallenges:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {"Lib:ApolloFixes-1.0", "Challenges"}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 
-----------------------------------------------------------------------------------------------
-- SlimChallenges OnLoad
-----------------------------------------------------------------------------------------------
function SlimChallenges:OnLoad()
	ChallengesBase_OnDocumentReady = challengesAddon.OnDocumentReady
	challengesAddon.OnDocumentReady = SlimChallenges.ChallengesHook_OnDocumentReady
	Apollo.RegisterTimerHandler("OneSecTimer", "OnTimer", self)	
end

function SlimChallenges.ChallengesHook_OnDocumentReady(challengesSelf)
	ChallengesBase_OnDocumentReady(challengesSelf)  -- this will create the Challenges
	local challenges = challengesSelf		
end

function SlimChallenges:OnTimer()
	if runOnce == true then
		local challengesRPAddon = Apollo.GetAddon("ChallengeRewardPanel")
		if challengesRPAddon ~= nil then
			challengesRPAddon.OnChallengeRewardShow = self.OnChallengeRewardShow
			challengesRPAddon.AddItem = self.AddItem
			--Print("RewardPanel loaded")
			ok = ok + 1
		end

		if challengesAddon ~= nil then
			challengesAddon.wndTracker:FindChild("TrackerBG"):SetOpacity(0.7)
			challengesAddon.wndTracker:FindChild("TrackerMinimizeButtonReplacement"):Show(false)
			challengesAddon.wndTracker:FindChild("TrackerTabContainer"):SetOpacity(0.7)
			local challengeDisplay = challengesAddon.wndTracker:FindChild("CompletedDisplay")
			if challengeDisplay ~= nil then
				challengeDisplay:FindChild("CompletedFooterArt"):Show(false)
				challengeDisplay:FindChild("CompletedStatus"):Show(false)
				challengeDisplay:FindChild("FailLootButton"):SetOpacity(0.7)
				challengeDisplay:FindChild("FailRetryButton"):SetOpacity(0.7)
				--Print("CompleteDisplay loaded")
				ok = ok + 1
			end
			challengeDisplay = challengesAddon.wndTracker:FindChild("BigDisplay")
			if challengeDisplay ~= nil then
				challengeDisplay:FindChild("TrackerOutcroppingArt"):SetSprite("BK3:sprGradientOutwards")
				challengeDisplay:FindChild("TrackerOutcroppingArt"):SetBGColor("UI_AlphaPercent25")
				challengeDisplay:FindChild("TrackerSeparatorArt"):Show(false)
				challengeDisplay:FindChild("TierCurrentProgressContainer"):SetOpacity(0.7)
				challengeDisplay:FindChild("TierSkillContainer"):SetOpacity(0.7)
				challengeDisplay:FindChild("TierMedalBG"):SetOpacity(0.7)
				challengeDisplay:FindChild("TrackerFlashAnimArt"):SetOpacity(0.7)
				--Print("BigDisplay loaded")
				ok = ok + 1
			end
		end
		if ok == 3 then
			runOnce = false
		else
			ok = 0
		end	
	end	
end


function SlimChallenges:OnChallengeRewardShow(idChallenge)
	self.idChallenge = idChallenge
	self.bInRandomizer = false
	self:DestroyItemList() -- We will wait for ChallengeRewardListReady to populate
	--self.wndText:SetText(Apollo.GetString("Challenges_Loading"))
	self.wndText:SetFont("CRB_InterfaceMedium")
	ChallengesLib.GenerateRewardList(idChallenge)
	self.wndMain:Show(true)
	--self.wndMain:FindChild("HoloFrame"):SetSprite("UI_BK3_Holo_InsetFramed")
	self.wndMain:FindChild("HoloFrame"):SetSprite("BK3:sprGradientOutwards")
	self.wndMain:FindChild("HoloFrame"):SetBGColor("UI_AlphaPercent45")
	self.wndMain:FindChild("HoloFrame"):SetScale(0.8)
	self.wndMain:FindChild("HoloFrame"):SetAnchorOffsets(55, 40, 55, 40)
	self.wndMain:FindChild("CloseButton"):SetAnchorOffsets(-90, 37, -48, 82)
	self.wndMain:ToFront()
end

function SlimChallenges:AddItem(idx, tRewards) -- add an item into the item list
	local wndChallengeItem = Apollo.LoadForm(self.xmlDoc, "ChallengeItem", self.wndItemList, self)
	self.tItems[idx] = wndChallengeItem -- keep track of the window item created
	self.nItems = self.nItems+1
	
	if tRewards.itemReward then
		wndChallengeItem:FindChild("LootIcon"):SetItemInfo(tRewards.itemReward, tRewards.nAmount)
	elseif tRewards.monReward then
		wndChallengeItem:FindChild("LootIcon"):SetMoneyInfo(tRewards.monReward, tRewards.nAmount)
	elseif tRewards.splReward then
		wndChallengeItem:FindChild("LootIcon"):SetSpellInfo(tRewards.splReward)
	elseif tRewards.nXp then
		wndChallengeItem:FindChild("LootIcon"):SetXpInfo(tRewards.nXp)
	elseif tRewards.nRepId then
		wndChallengeItem:FindChild("LootIcon"):SetReputationInfo(tRewards.nRepId, tRewards.nRepAmount)
	end

	self.tTierCounts[tRewards.nChallengeTier] = self.tTierCounts[tRewards.nChallengeTier] + 1
	
	--wndChallengeItem:FindChild("ChallengeItemBtn"):SetBGColor(CColor.new(1.0, 1.0, 1.0, 1.0))
	wndChallengeItem:FindChild("ChallengeItemBtn"):SetSprite("BK3:sprGradientOutwards")
	wndChallengeItem:FindChild("ChallengeItemBtn"):SetBGColor("UI_AlphaPercent35")
	wndChallengeItem:FindChild("Backer"):SetBGColor(CColor.new(1.0, 1.0, 1.0, 1.0))		
	wndChallengeItem:FindChild("LootIcon"):SetBGColor(CColor.new(1.0, 1.0, 1.0, 1.0))
	wndChallengeItem:FindChild("2xMarker"):SetText(String_GetWeaselString(Apollo.GetString("ChallengeReward_Multiplier"), ChallengesLib.GetLootBonusMultiplier(self.iRewardTier)))
	wndChallengeItem:FindChild("2xMarker"):SetTextColor(kcrDoubleMarkerOff)
	self.tValidWindows[idx] = wndChallengeItem
	wndChallengeItem:FindChild("LootIconBlocker"):SetBGColor(CColor.new(0, 0, 0, 0))
	wndChallengeItem:FindChild("LootIconBlocker"):SetData(true)	
	wndChallengeItem:FindChild("LootIconBlocker"):Enable(true)

	wndChallengeItem:FindChild("ChallengeItemBtn"):Enable(true)
	wndChallengeItem:FindChild("2xMarker"):Show(true)

	wndChallengeItem:SetData(idx)
end


-----------------------------------------------------------------------------------------------
-- SlimChallenges Instance
-----------------------------------------------------------------------------------------------
local SlimChallengesInst = SlimChallenges:new()
SlimChallengesInst:Init()
